@@ -1,22 +1,24 @@
 package JSON::Validator;
 use Mojo::Base -base;
 
+use B;
+use Carp ();
 use Exporter 'import';
 use JSON::Validator::Error;
 use Mojo::File 'path';
-use Mojo::JSON;
 use Mojo::JSON::Pointer;
+use Mojo::JSON;
 use Mojo::URL;
 use Mojo::Util 'deprecated';
-use B;
 use Scalar::Util;
 
 use constant VALIDATE_HOSTNAME => eval 'require Data::Validate::Domain;1';
 use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
+use constant SPECIFICATION_URL => 'http://json-schema.org/draft-04/schema#';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.94';
+our $VERSION = '0.95';
 our @EXPORT_OK = 'validate_json';
 
 my $BUNDLED_CACHE_DIR = path(path(__FILE__)->dirname, qw(Validator cache));
@@ -59,6 +61,17 @@ sub coerce {
   $self;
 }
 
+sub load_and_validate_schema {
+  my ($self, $spec, $args) = @_;
+  my $clone = JSON::Validator->new->schema($spec)->schema->data;
+  my @errors = JSON::Validator->new->schema($args->{schema} || SPECIFICATION_URL)->validate($clone);
+
+  Carp::confess(join "\n", "Invalid schema:", @errors) if @errors;
+  warn "[JSON::Validator] Loaded $spec\n" if DEBUG;
+  $self->{schema} = $clone;
+  $self;
+}
+
 sub schema {
   my ($self, $schema) = @_;
 
@@ -127,7 +140,7 @@ sub _load_schema {
   elsif ($parent) {
     $url =~ s!#.*!!;
     $url = path(path($parent)->dirname, split '/', $url);
-    $namespace = eval { $url->to_abs->to_string } || $url;
+    $namespace = Cwd::abs_path($url->to_string) || $url;
   }
 
   # Make sure we create the correct namespace if not already done by Mojo::URL
@@ -800,7 +813,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.94
+0.95
 
 =head1 SYNOPSIS
 
@@ -1092,10 +1105,32 @@ The coercion rules are EXPERIMENTAL and will be tighten/loosen if
 bugs are reported. See L<https://github.com/jhthorsen/json-validator/issues/8>
 for more details.
 
+=head2 load_and_validate_schema
+
+  $self = $self->load_and_validate_schema($schema, \%args);
+
+Will load and validate C<$schema> against the OpenAPI specification. C<$schema>
+can be anything L<JSON::Validator/schema> accepts. The expanded specification
+will be stored in L<JSON::Validator/schema> on success. See
+L<JSON::Validator/schema> for the different version of C<$url> that can be
+accepted.
+
+C<%args> can be used to further instruct the validation process:
+
+=over 2
+
+=item * schema
+
+Defaults to "http://json-schema.org/draft-04/schema#", but can be any
+structured that can be used to validate C<$schema>.
+
+=back
+
 =head2 schema
 
-  $self = $self->schema(\%schema);
+  $self = $self->schema($json_or_yaml_string);
   $self = $self->schema($url);
+  $self = $self->schema(\%schema);
   $schema = $self->schema;
 
 Used to set a schema from either a data structure or a URL.
